Rdocumentation
powered by
Learn R Programming
CausalR (version 1.4.3)
GetScoresWeightsMatrixByCubicAlg: get scores weights matrix by the cubic algorithm
Description
Implements the cubic algorithm as described on pages 6 and 7 of Assessing statistical significance in causal graphs, Chindelevitch et al. 2012
Usage
GetScoresWeightsMatrixByCubicAlg(predictionListStats, experimentalDataStats, epsilon)
Arguments
predictionListStats
a vector containing the values q+, q- and q0
experimentalDataStats
a vector containing the values n+, n- and n0
epsilon
the algorithms tolerance epsilon
Value
a matrix containing the ternary dot product distribution
References
L Chindelevitch et al. Assessing statistical significance in causal graphs. BMC Bioinformatics, 13(35), 2012.