Rdocumentation
powered by
Learn R Programming
CausalR (version 1.4.3)
GetWeightsFromInteractionInformation: get weights from interaction information
Description
Returns a matrix of weights (-1,0,+1) indicating the direction of regulation from the interaction information.
Usage
GetWeightsFromInteractionInformation(interactionInfo)
Arguments
interactionInfo
a central column of the .sif file, giving the type of edge interaction
Value
a matrix of weights corresponding the the direction of regulation